@@ -118,7 +118,7 @@ class Task(object):
 
     @none_on_exception(AttributeError)
     def GetContexts(self):
-        occurs = re.findall("(^|\s)@([^ ]+)", self.text)
+        occurs = re.findall(r"(^|\s)@([^ ]+)", self.text)
         return sorted([x[1] for x in occurs])
 
     @none_on_exception(AttributeError)
@@ -157,11 +157,13 @@ def parse_args():
 
 def cleanup(filepath):
     with open(filepath, "r", encoding="utf-8") as fp:
-        projects = Projects(fp.read())
-
-    with open(filepath, "w", encoding="utf-8") as fp:
-        fp.write(str(projects))
+        instr = fp.read()
+        projects = Projects(instr)
 
+    outstr = str(projects)
+    if outstr != instr:
+        with open(filepath, "w", encoding="utf-8") as fp:
+            fp.write(outstr)
 
 def main():
     args = parse_args()
